//[mahjong-utils](../../../index.md)/[mahjongutils.hora](../index.md)/[ChitoiHoraHandPattern](index.md)/[remaining](remaining.md)

# remaining

[common]\
open override val [remaining](remaining.md): [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../mahjongutils.models/-tile/index.md)&gt;

浮牌
